@@ -307,31 +307,37 @@ pub(crate) fn get_meminfo_value(value: &str) -> u64 {
 #[cfg(not(target_os = "windows"))]
 pub(crate) fn logical_address(interface: Option<&str>) -> Result<String, ReadoutError> {
     if let Some(ifname) = interface {
-        if let Ok(addresses) = if_addrs::get_if_addrs() {
-            let address = addresses
-                .iter()
-                .find(|i| i.name.eq_ignore_ascii_case(ifname));
+        if let Some(addr) = if_addrs::get_if_addrs()?.into_iter().find_map(|i| {
+            if i.name.ne(ifname) {
+                return None;
+            }
 
-            return match address {
-                Some(addr) => Ok(addr.ip().to_string()),
-                _ => Err(ReadoutError::Other(format!(
-                    "\"{}\" doesn't exist.",
-                    ifname
-                ))),
-            };
-        }
+            if i.addr.is_loopback() {
+                return None;
+            }
 
-        Err(ReadoutError::Other(format!("\"{}\" is offline.", ifname)))
-    } else {
-        Err(ReadoutError::Other("No interface specified.".to_owned()))
+            if let if_addrs::IfAddr::V4(v4_addr) = i.addr {
+                return Some(v4_addr);
+            }
+
+            None
+        }) {
+            return Ok(addr.ip.to_string());
+        };
     }
+    Err(ReadoutError::Other(String::from(
+        "Unable to get local IPv4 address.",
+    )))
 }
 
 pub(crate) fn count_cargo() -> Option<usize> {
     if let Ok(cargo_home) = home::cargo_home() {
         let bin = cargo_home.join("bin");
         if let Ok(read_dir) = read_dir(bin) {
-            return Some(read_dir.count());
+            match read_dir.count() {
+                0 => None,
+                pkgs => Some(pkgs),
+            };
         }
     }
 
